@@ -5,7 +5,7 @@ package Dist::Zilla::PluginBundle::SHANTANU;
 
 # PODNAME: Dist::Zilla::PluginBundle::SHANTANU
 
-our $VERSION = '0.28'; # VERSION
+our $VERSION = '0.38'; # VERSION
 
 # Dependencies
 use 5.010;
@@ -197,6 +197,18 @@ has no_coverage => (
 );
 
 
+has test_compile => (
+    is      => 'ro',
+    isa     => 'Bool',
+    lazy    => 1,
+    default => sub {
+        exists $_[0]->payload->{test_compile}
+          ? $_[0]->payload->{test_compile}
+          : 1;
+    },
+);
+
+
 has auto_prereq => (
     is      => 'ro',
     isa     => 'Bool',
@@ -263,7 +275,7 @@ has git_remote => (
 sub configure {
     my $self = shift;
 
-    my @push_to = ('origin');
+    my @push_to = ( 'origin', 'origin build/master' );
     push @push_to, $self->git_remote if $self->git_remote ne 'origin';
 
     $self->add_plugins(
@@ -324,7 +336,11 @@ sub configure {
         'License',    # core
 
         # generated t/ tests
-        [ 'Test::Compile'        => { fake_home       => 1 } ],
+        (
+            $self->test_compile
+            ? [ 'Test::Compile' => { fake_home => 1 } ]
+            : ()
+        ),
         [ 'Test::MinimumVersion' => { max_target_perl => '5.010' } ],
         'Test::ReportPrereqs',
 
@@ -372,7 +388,6 @@ sub configure {
             ? ()
             : ('PodCoverageTests')    # core
         ),
-        [ 'Test::Portability' => { options => "test_one_dot = 0" } ],
         'Test::Version',
 
         # metadata
@@ -395,7 +410,6 @@ sub configure {
         'MetaYAML'
         ,    # core : Helps avoid kwalitee croaks and supports older systems
         'MetaJSON',    # core
-        'TravisYML',
         [
             'ChangelogFromGit::CPAN::Changes' => {
                 tag_regexp             => $self->tag_regexp,
@@ -484,11 +498,8 @@ sub configure {
             ? ()
             : (
                 [
-                    'Git::Commit' => 'Commit_Dirty_Files' => {
-                        allow_dirty => [
-                            qw/dist.ini Changes README.md README.pod META.json META.yml .travis.yml/
-                        ]
-                    }
+                    'Git::Commit' => 'Commit_Dirty_Files' =>
+                      { allow_dirty => [qw/dist.ini README.md .travis.yml/] }
                 ],
                 [ 'Git::Tag' => { tag_format => $self->tag_format } ],
             )
@@ -539,7 +550,7 @@ Dist::Zilla::PluginBundle::SHANTANU - Dist Zilla Plugin Bundle the way I like to
 
 =head1 VERSION
 
-version 0.28
+version 0.38
 
 =head1 SYNOPSIS
 
@@ -606,6 +617,10 @@ Skip Perl Critic Checks
 
 Skip Pod Coverage tests
 
+=head2 test_compile
+
+Create compile tests.
+
 =head2 auto_prereq
 
 Automatically get prerequisites(default 1)
@@ -750,29 +765,11 @@ L<https://github.com/shantanubhadoria/perl-dist-zilla-pluginbundle-shantanu>
 
 Shantanu Bhadoria <shantanu@cpan.org> L<https://www.shantanubhadoria.com>
 
-=head1 CONTRIBUTORS
+=head1 CONTRIBUTOR
 
 =for stopwords Shantanu Bhadoria
 
-=over 4
-
-=item *
-
-Shantanu <shantanu@cpan.org>
-
-=item *
-
-Shantanu Bhadoria <shantanu.bhadoria@gmail.com>
-
-=item *
-
-Shantanu Bhadoria <shantanu@cpan.org>
-
-=item *
-
-Shantanu Bhadoria <shantanu@shantanu-M14xR2.(none)>
-
-=back
+Shantanu Bhadoria <shantanu att cpan dott org>
 
 =head1 COPYRIGHT AND LICENSE
 
